from dapla_auth_client import AuthClient

from dapla_metadata._shared.config import get_config_item
from dapla_metadata._shared.config import get_dapla_environment
from dapla_metadata._shared.enums import DaplaEnvironment
from dapla_metadata.variable_definitions._generated.vardef_client.configuration import (
    Configuration,
)

VARDEF_HOST_PROD = "https://metadata.intern.ssb.no"
VARDEF_HOST_TEST = "https://metadata.intern.test.ssb.no"
WORKSPACE_DIR = "WORKSPACE_DIR"


def get_workspace_dir() -> str | None:
    """Get the path to work directory from workspace environment variable."""
    return get_config_item(WORKSPACE_DIR)


def get_vardef_host() -> str:
    """Get the host for the server to make requests to.

    Based on standard Dapla platform environment variables, or variables specific
    to Vardef if these are not available.

    Raises:
        NotImplementedError: When Vardef is not available for the current environment.
    """
    match get_dapla_environment():
        case DaplaEnvironment.PROD:
            return VARDEF_HOST_PROD
        case DaplaEnvironment.TEST:
            return VARDEF_HOST_TEST
        case DaplaEnvironment.DEV:
            return VARDEF_HOST_TEST
        case _:
            return get_config_item("VARDEF_HOST") or "http://localhost:8080"


def refresh_access_token() -> str:
    return AuthClient.fetch_personal_token(
        scopes=["all_groups", "current_group"], audiences=["vardef"]
    )


def get_vardef_client_configuration() -> Configuration:
    """Build a config to be supplied to the `ApiClient`."""
    return Configuration(host=get_vardef_host(), access_token=refresh_access_token())



import shutil
import tempfile
from pathlib import Path

import pytest


@pytest.fixture
def set_temp_bucket(tmp_path: Path):
    """Fixture which set buckets."""
    buckets_dir = tmp_path / "buckets"
    buckets_dir.mkdir(parents=True, exist_ok=True)
    return buckets_dir


@pytest.fixture
def set_temp_bucket_name(set_temp_bucket):
    """Fixture which set buckets."""
    buckets_name_folder = set_temp_bucket / "bucket_name"
    buckets_name_folder.mkdir(parents=True, exist_ok=True)
    return buckets_name_folder


@pytest.fixture(scope="module")
def test_directory():
    """Creates a temporary directory with test files and subdirectories."""
    temp_dir = Path(tempfile.mkdtemp())  # Create temp directory

    # Create valid and invalid files
    (
        temp_dir
        / "ssb-staging-dapla-felles-data-delt/datadoc/utdata/person_data_p2021_v2.parquet"
    ).touch()
    (
        temp_dir / "stat/inndata/person_testdata_p2021-12-31_p2021-12-31_v1.parquet"
    ).touch()
    (
        temp_dir
        / "ssb-dapla-example-data-produkt-prod/ledstill/inndata/skjema_p2018_p2020_v1"
    ).touch()
    (
        temp_dir
        / "tests/dataset/klargjorte_data/arbmark/resources/person_data_v1.parquet"
    ).touch()

    # Create a subdirectory with more files
    sub_dir = temp_dir / "subdir"
    sub_dir.mkdir()
    (
        sub_dir / "produkt/test-2/person_testdata_p2021-12-31_p2021-12-31_v1.parquet"
    ).touch()

    yield temp_dir  # Provide temp directory path to tests

    shutil.rmtree(temp_dir)  # Cleanup after tests



from datetime import date

VARDEF_EXAMPLE_DEFINITION_ID = "wypvb3wd"
VARDEF_EXAMPLE_INVALID_ID = "invalid id"
VARDEF_EXAMPLE_SHORT_NAME = "landbak"
VARDEF_EXAMPLE_DATE = date(1970, 1, 1)
CONSTRAINT_VIOLATION_BODY = """{
    "cause": null,
    "suppressed": [
    ],
    "detail": null,
    "instance": null,
    "parameters": {
    },
    "type": "https://zalando.github.io/problem/constraint-violation",
    "title": "Constraint Violation",
    "status": 400,
    "violations": [
        {
            "field": "updateVariableDefinitionById.updateDraft.owner.team",
            "message": "Invalid Dapla team"
        },
        {
            "field": "updateVariableDefinitionById.updateDraft.owner.team",
            "message": "must not be empty"
        }
    ]
}"""
CONSTRAINT_VIOLATION_BODY_MISSING_MESSAGES = """{
    "cause": null,
    "suppressed": [
    ],
    "detail": null,
    "instance": null,
    "parameters": {
    },
    "type": "https://zalando.github.io/problem/constraint-violation",
    "title": "Constraint Violation",
    "status": 400,
    "violations": [
        {
            "field": "updateVariableDefinitionById.updateDraft.owner.team"
        },
        {
            "field": "updateVariableDefinitionById.updateDraft.owner.team"
        }
    ]
}"""

CONSTRAINT_VIOLATION_BODY_MISSING_VIOLATIONS = """{
    "cause": null,
    "suppressed": [
    ],
    "detail": null,
    "instance": null,
    "parameters": {
    },
    "type": "https://zalando.github.io/problem/constraint-violation",
    "title": "Constraint Violation",
    "status": 400,
    "violations": []
}"""
CONSTRAINT_VIOLATION_BODY_MISSING_FIELD = """{
    "cause": null,
    "suppressed": [
    ],
    "detail": null,
    "instance": null,
    "parameters": {
    },
    "type": "https://zalando.github.io/problem/constraint-violation",
    "title": "Constraint Violation",
    "status": 400,
    "violations": [
        {
            "message": "Invalid Dapla team"
        },
        {
            "message": "must not be empty"
        }
    ]
}"""
